permissions_map = {
    0: "Default permissions (will pick the one from the next level of: user, call, conversation)",
    1: "Custom permissions (this is required to be able to remove all other permissions)",
    2: "Start call",
    4: "Join call",
    8: "Can ignore lobby",
    16: "Can publish audio stream",
    32: "Can publish video stream",
    64: "Can publish screen sharing stream",
    128: "Can post chat message, share items and do reactions"}
